#
# spec file for package python-applicationinsights
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-applicationinsights
Version:        0.11.10
Release:        4.1
Summary:        Microsoft Application Insights for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/applicationinsights/applicationinsights-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-applicationinsights <= 0.11.10
%endif
BuildArch:      noarch

%python_subpackages

%description
This project extends the Application Insights API surface to support Python.

Application Insights is a service that allows developers to keep their
application available, performing and succeeding. This Python module will
allow you to send telemetry of various kinds (event, trace, exception, etc.)
to the Application Insights service where they can be visualized in the
Azure Portal.

%prep
%setup -q -n applicationinsights-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE.txt
%{python_sitelib}/applicationinsights
%{python_sitelib}/applicationinsights-*.dist-info

%changelog
* Fri May  3 2024 Robert Schweikert <rjschwei@suse.com>
- Change version setting of Obsoletes to <= to trigger python3
  binary removal since there was no source version bump
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
* Thu Mar 21 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Limit Python files matched in %%files section
* Tue Nov  2 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.11.10
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.11.9
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Apr 10 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.11.7
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Mon Sep  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.11.6
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Install CHANGELOG.md into doc directory
- Rename README.md to README.rst in spec file
* Tue Apr 24 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.11.2
  + Upstream changelog not available
- Move LICENSE.txt from %%doc to %%license section
* Fri Sep 15 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.11.1
